@@ -3,6 +3,7 @@ __author__ = 'schlitzer'
 
 __all__ = [
     'PyRedisError',
+    'PyRedisURLError',
     'PyRedisConnError',
     'PyRedisConnClosed',
     'PyRedisConnReadTimeout',
@@ -15,6 +16,10 @@ class PyRedisError(Exception):
     pass
 
 
+class PyRedisURLError(PyRedisError):
+    pass
+
+
 class PyRedisConnError(PyRedisError):
     pass
 
