@@ -38,12 +38,23 @@ def slot_from_key(key):
 
 
 class ClusterMap(object):
-    def __init__(self, seeds, password=None, lock=Lock()):
+    def __init__(
+            self,
+            seeds,
+            password=None,
+            lock=None,
+            username=None,
+
+    ):
         self._id = uuid4()
-        self._lock = lock
+        if not lock:
+            self._lock = Lock()
+        else:
+            self._lock = lock
         self._map = {}
         self._seeds = deque(seeds)
         self._password = password
+        self._username = username
 
     @property
     def id(self):
@@ -55,7 +66,13 @@ class ClusterMap(object):
 
     def _fetch_map(self):
         for seed in self._seeds:
-            conn = Connection(host=seed[0], port=seed[1], encoding='utf-8', password=self._password)
+            conn = Connection(
+                host=seed[0],
+                port=seed[1],
+                encoding='utf-8',
+                password=self._password,
+                username=self._username
+            )
             try:
                 conn.write(b'CLUSTER', b'SLOTS')
                 return conn.read()
